----------------------------------------------------
------------------ AthComboPoints ------------------
----------------------------------------------------
-- Author: Athariel / trysor

-- CHANGE THESE TO REPOSITION THE COMBO POINTS
local anchorPoint = "CENTER";
local relativeTo = UIParent;
local relativePoint = "CENTER";
local posX = 100; -- left to right (0 == left)
local posY = -50; -- top to bottom (0 == top)

----------------------------------------------------
-------------- Combo Point Functions ---------------
----------------------------------------------------
local class = strlower(select(2, UnitClass("Player")));
local classes = {
	["rogue"] = 5, -- anticipation below
	["druid"] = 5, 
	["monk"] = 5, -- 4 + 1 (talent)
	["paladin"] = 5 -- 3 + 2
};

-- don't load rest if not a supported class
if classes[class] == nil then return; end

-- often used functions
local GetComboPoints = GetComboPoints;
local UnitPower = UnitPower;
-- often used globals
local SPELL_POWER_CHI = SPELL_POWER_CHI;
local SPELL_POWER_HOLY_POWER = SPELL_POWER_HOLY_POWER;
-- simplify caller
local class_resource_func = {
	["rogue"] = function() return GetComboPoints("player") end,
	["druid"] = function() return GetComboPoints("player") end,
	["monk"] = function() return UnitPower("player", SPELL_POWER_CHI) end,
	["paladin"] = function() return UnitPower("player", SPELL_POWER_HOLY_POWER) end,
};

----------------------------------------------------
------------------- Frame config -------------------
----------------------------------------------------
local frame = CreateFrame("frame", nil, UIParent);
frame:SetFrameStrata("BACKGROUND");
frame:SetHeight(90);
frame:SetWidth(35);
frame:SetPoint(anchorPoint, relativeTo, relativePoint, posX, posY);

----------------------------------------------------
-------------------- CP creation -------------------
----------------------------------------------------
local function createCPs(column)
	local f = CreateFrame("frame", nil, frame);
	for i = 1, classes[class] do
		tinsert(f, CreateFrame("frame", nil, frame));

		local CP = f[i];
		CP:SetHeight(15);
		CP:SetWidth(15);

		CP.Texture = CP:CreateTexture();
		CP.Texture:SetAllPoints(CP);
		CP.Texture:SetTexture("Interface\\ComboFrame\\ComboPoint");
		CP.Texture:SetTexCoord(0,0.375,0,0.8);
		if (column == 0) then CP.Texture:SetVertexColor(0.8, 0.2, 0.2);
		else CP.Texture:SetVertexColor(0.6, 0.2, 1); end

		CP:SetPoint("TOPLEFT", frame, "TOPLEFT", column*20, -(18)*(i-1));
	end
	return f;
end

----------------------------------------------------
--------------------- CP Frame ---------------------
----------------------------------------------------
frame.CP = createCPs(0); -- column 0
local function updateCP()
	for i = 1, classes[class] do
		if i > class_resource_func[class]() then
			frame.CP[i]:Hide();
		else
			frame.CP[i]:Show();
		end
	end
end
updateCP();

----------------------------------------------------
------------------ Register Events -----------------
----------------------------------------------------
if class == "rogue" or class == "druid" then
	frame.CP:RegisterEvent("UNIT_COMBO_POINTS");
	frame.CP:RegisterEvent("PLAYER_TARGET_CHANGED");
	frame.CP:SetScript("OnEvent", updateCP);
else
	frame.CP:RegisterEvent("UNIT_POWER");
	local r = { ["paladin"] = "HOLY_POWER", ["monk"] = "CHI", }
	frame.CP:SetScript("OnEvent", function(self, event, arg1, arg2)
		if arg1 == "player" and arg2 == r[class] then updateCP(); end
	end);
end

----------------------------------------------------
------------------- ANTICIPATION -------------------
----------------------------------------------------
-- the code below apply to ONLY rogues
if class ~= "rogue" then return; end

-- often used functions
local UnitAura = UnitAura;

frame.Anticipation = createCPs(1); -- column 1
frame.Anticipation:RegisterEvent("UNIT_AURA");

local function updateAnticipation(self, event, arg1)
	if arg1 ~= "player" then return end
	local _, _, _, count = UnitAura("player", "Anticipation");
	for i = 1,5 do
		if (not count) or (i > count) then
			frame.Anticipation[i]:Hide();
		else
			frame.Anticipation[i]:Show();
		end
	end
end

frame.Anticipation:SetScript("OnEvent", updateAnticipation);
updateAnticipation(frame.Anticipation, "UNIT_AURA", "player");


